@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
+    Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -22,7 +22,25 @@
 #include <QTimer>
 #include <KIconLoader>
 
-namespace KPIM {
+using namespace KPIM;
+class KPIM::ProgressIndicatorWidgetPrivate
+{
+public:
+    ProgressIndicatorWidgetPrivate(ProgressIndicatorWidget *qq)
+        : q(qq)
+    {
+        indicator = new IndicatorProgress(q);
+    }
+
+    ~ProgressIndicatorWidgetPrivate()
+    {
+        delete indicator;
+    }
+
+    IndicatorProgress *indicator = nullptr;
+    ProgressIndicatorWidget *q = nullptr;
+};
+
 IndicatorProgress::IndicatorProgress(ProgressIndicatorWidget *widget, QObject *parent)
     : QObject(parent)
     , mProgressCount(0)
@@ -70,23 +88,6 @@ bool IndicatorProgress::isActive() const
     return mIsActive;
 }
 
-class ProgressIndicatorWidgetPrivate
-{
-public:
-    ProgressIndicatorWidgetPrivate(ProgressIndicatorWidget *qq)
-        : q(qq)
-    {
-        indicator = new IndicatorProgress(q);
-    }
-
-    ~ProgressIndicatorWidgetPrivate()
-    {
-        delete indicator;
-    }
-
-    IndicatorProgress *indicator;
-    ProgressIndicatorWidget *q;
-};
 
 ProgressIndicatorWidget::ProgressIndicatorWidget(QWidget *parent)
     : QLabel(parent)
@@ -114,4 +115,4 @@ bool ProgressIndicatorWidget::isActive() const
 {
     return d->indicator->isActive();
 }
-}
+
