@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -19,11 +19,7 @@
 #define ADDRESSEELINEEDIT_P_H
 #include <QStringList>
 #include <QObject>
-#include <QTimer>
 #include <QList>
-#include <QColor>
-#include <ContactGroupSearchJob>
-#include "Libkdepim/LdapClient"
 #include "ldap/ldapclientsearch.h"
 #include <AkonadiCore/Item>
 #include <AkonadiCore/Collection>
@@ -31,6 +27,10 @@
 
 class KConfig;
 class QToolButton;
+class QTimer;
+namespace Akonadi {
+class ContactGroupSearchJob;
+}
 
 namespace KPIM {
 class AddresseeLineEdit;
@@ -40,9 +40,6 @@ class AddresseeLineEditPrivate : public QObject
 public:
     AddresseeLineEditPrivate(AddresseeLineEdit *qq, bool enableCompletion);
     ~AddresseeLineEditPrivate();
-    QStringList cleanupEmailList(const QStringList &inputList);
-    void loadBalooBlackList();
-    void alternateColor();
     void init();
     void setCompletedItems(const QStringList &items, bool autoSuggest);
     void addCompletionItem(const QString &string, int weight, int source, const QStringList *keyWords = nullptr);
@@ -54,7 +51,6 @@ public:
     void doCompletion(bool ctrlT);
 
     bool showOU() const;
-    void setShowOU(bool showOU);
 
     void setIcon(const QIcon &icon, const QString &tooltip);
 
@@ -62,7 +58,6 @@ public:
     void setUseCompletion(bool useCompletion);
 
     bool completionInitialized() const;
-    void setCompletionInitialized(bool completionInitialized);
 
     bool smartPaste() const;
     void setSmartPaste(bool smartPaste);
@@ -89,7 +84,6 @@ public:
     void updateCompletionOrder();
 
     KLDAP::LdapClientSearch *ldapSearch();
-    QStringList balooBlackList() const;
 
     void setExpandIntern(bool);
     bool expandIntern() const;
@@ -119,6 +113,7 @@ public:
     void setCanDeleteLineEdit(bool inprogressToConfigureCompletion);
 
 public Q_SLOTS:
+    void slotToggleExpandGroups(bool);
     void slotShowOUChanged(bool);
 
 private Q_SLOTS:
@@ -136,31 +131,25 @@ private Q_SLOTS:
     void slotTriggerDelayedQueries();
 
 private:
-    AddresseeLineEdit *q;
-    QToolButton *m_toolButton;
-    QTimer m_delayedQueryTimer;
-    QColor m_alternateColor;
-    QStringList m_balooBlackList;
-    QStringList m_domainExcludeList;
-    QString m_previousAddresses;
-    QString m_searchString;
+    AddresseeLineEdit *q = nullptr;
+    QToolButton *mToolButton = nullptr;
+    QTimer *mDelayedQueryTimer = nullptr;
+    QString mPreviousAddresses;
+    QString mSearchString;
     QList<KJob *> mMightBeGroupJobs;
     KContacts::ContactGroup::List mGroups;
-    KConfig *m_recentAddressConfig;
-    bool m_useCompletion;
-    bool m_completionInitialized;
-    bool m_smartPaste;
-    bool m_addressBookConnected;
-    bool m_lastSearchMode;
-    bool m_searchExtended; //has \" been added?
-    bool m_useSemicolonAsSeparator;
-    bool m_showOU;
-    bool m_enableBalooSearch;
-    bool m_enableAkonadiSearch;
-    bool mExpandIntern;
-    bool mAutoGroupExpand;
-    bool mShowRecentAddresses;
-    bool mCanDeleteLineEdit;
+    KConfig *mRecentAddressConfig = nullptr;
+    bool mUseCompletion = false;
+    bool mCompletionInitialized = false;
+    bool mSmartPaste = false;
+    bool mLastSearchMode = false;
+    bool mSearchExtended = false; //has \" been added?
+    bool mUseSemicolonAsSeparator = false;
+    bool mEnableBalooSearch = true;
+    bool mEnableAkonadiSearch = true;
+    bool mExpandIntern = true;
+    bool mShowRecentAddresses = true;
+    bool mCanDeleteLineEdit = true;
 };
 }
 
