@@ -1,5 +1,5 @@
 /*
-  Copyright 2013-2017 Laurent Montel <montel@kde.org>
+  Copyright 2013-2018 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
@@ -74,7 +74,9 @@ public:
         searchJob->setLimit(1);
         searchJob->setQuery(Akonadi::ContactSearchJob::Email, mEmail.toLower(),
                             Akonadi::ContactSearchJob::ExactMatch);
-        q->connect(searchJob, SIGNAL(result(KJob *)), q, SLOT(slotSearchDone(KJob *)));
+        q->connect(searchJob, &Akonadi::ContactSearchJob::result, q, [this](KJob *job) {
+            slotSearchDone(job);
+        });
     }
 
     void modifyContact()
@@ -86,7 +88,9 @@ public:
             address.insertCustom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("MailAllowToRemoteContent"), mRemoteContent ? QStringLiteral("TRUE") : QStringLiteral("FALSE"));
             item.setPayload<KContacts::Addressee>(address);
             Akonadi::ItemModifyJob *job = new Akonadi::ItemModifyJob(item);
-            q->connect(job, SIGNAL(result(KJob *)), SLOT(slotAddModifyContactDone(KJob *)));
+            q->connect(job, &Akonadi::ItemModifyJob::result, q, [this](KJob *job) {
+                slotAddModifyContactDone(job);
+            });
         } else {
             searchContact();
         }
@@ -113,7 +117,9 @@ public:
             contact.insertCustom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("MailAllowToRemoteContent"), mRemoteContent ? QStringLiteral("TRUE") : QStringLiteral("FALSE"));
             item.setPayload<KContacts::Addressee>(contact);
             Akonadi::ItemModifyJob *job = new Akonadi::ItemModifyJob(item);
-            q->connect(job, SIGNAL(result(KJob *)), SLOT(slotAddModifyContactDone(KJob *)));
+            q->connect(job, &Akonadi::ItemModifyJob::result, q, [this](KJob *job) {
+                slotAddModifyContactDone(job);
+            });
         }
     }
 
@@ -126,7 +132,9 @@ public:
                                               Akonadi::CollectionFetchJob::Recursive);
 
         addressBookJob->fetchScope().setContentMimeTypes(mimeTypes);
-        q->connect(addressBookJob, SIGNAL(result(KJob *)), SLOT(slotCollectionsFetched(KJob *)));
+        q->connect(addressBookJob, &Akonadi::CollectionFetchJob::result, q, [this](KJob *job) {
+            slotCollectionsFetched(job);
+        });
     }
 
     void slotCollectionsFetched(KJob *job)
@@ -158,29 +166,34 @@ public:
                     i18nc("@info",
                           "You must create an address book before adding a contact. Do you want to create an address book?"),
                     i18nc("@title:window", "No Address Book Available")) == KMessageBox::Yes) {
-                Akonadi::AgentTypeDialog dlg(mParentWidget);
-                dlg.setWindowTitle(i18n("Add Address Book"));
-                dlg.agentFilterProxyModel()->addMimeTypeFilter(KContacts::Addressee::mimeType());
-                dlg.agentFilterProxyModel()->addMimeTypeFilter(KContacts::ContactGroup::mimeType());
-                dlg.agentFilterProxyModel()->addCapabilityFilter(QStringLiteral("Resource"));
+                QPointer<Akonadi::AgentTypeDialog> dlg = new Akonadi::AgentTypeDialog(mParentWidget);
+                dlg->setWindowTitle(i18n("Add Address Book"));
+                dlg->agentFilterProxyModel()->addMimeTypeFilter(KContacts::Addressee::mimeType());
+                dlg->agentFilterProxyModel()->addMimeTypeFilter(KContacts::ContactGroup::mimeType());
+                dlg->agentFilterProxyModel()->addCapabilityFilter(QStringLiteral("Resource"));
 
-                if (dlg.exec()) {
-                    const Akonadi::AgentType agentType = dlg.agentType();
+                if (dlg->exec()) {
+                    const Akonadi::AgentType agentType = dlg->agentType();
 
                     if (agentType.isValid()) {
                         Akonadi::AgentInstanceCreateJob *job = new Akonadi::AgentInstanceCreateJob(agentType, q);
-                        q->connect(job, SIGNAL(result(KJob *)), SLOT(slotResourceCreationDone(KJob *)));
+                        q->connect(job, &Akonadi::AgentInstanceCreateJob::result, q, [this](KJob *job) {
+                            slotResourceCreationDone(job);
+                        });
                         job->configure(mParentWidget);
                         job->start();
+                        delete dlg;
                         return;
                     } else { //if agent is not valid => return error and finish job
                         q->setError(UserDefinedError);
                         q->emitResult();
+                        delete dlg;
                         return;
                     }
                 } else { //Canceled create agent => return error and finish job
                     q->setError(UserDefinedError);
                     q->emitResult();
+                    delete dlg;
                     return;
                 }
             } else {
@@ -226,7 +239,9 @@ public:
 
         // save the new item in akonadi storage
         Akonadi::ItemCreateJob *createJob = new Akonadi::ItemCreateJob(item, addressBook, q);
-        q->connect(createJob, SIGNAL(result(KJob *)), SLOT(slotAddModifyContactDone(KJob *)));
+        q->connect(createJob, &Akonadi::ItemCreateJob::result, q, [this](KJob *job) {
+            slotAddModifyContactDone(job);
+        });
     }
 
     void slotAddModifyContactDone(KJob *job)
@@ -240,12 +255,12 @@ public:
 
     AddEmailDiplayJob *q;
     Akonadi::Item contact;
-    bool mShowAsHTML;
-    bool mRemoteContent;
+    bool mShowAsHTML = false;
+    bool mRemoteContent = false;
     QString mCompleteAddress;
     QString mEmail;
     QString mName;
-    QWidget *mParentWidget;
+    QWidget *mParentWidget = nullptr;
 };
 
 AddEmailDiplayJob::AddEmailDiplayJob(const QString &email, QWidget *parentWidget, QObject *parent)
